# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from . import _utilities, _tables

__all__ = [
    'ProviderBatching',
]

@pulumi.output_type
class ProviderBatching(dict):
    def __init__(__self__, *,
                 enable_batching: Optional[bool] = None,
                 send_after: Optional[str] = None):
        if enable_batching is not None:
            pulumi.set(__self__, "enable_batching", enable_batching)
        if send_after is not None:
            pulumi.set(__self__, "send_after", send_after)

    @property
    @pulumi.getter(name="enableBatching")
    def enable_batching(self) -> Optional[bool]:
        return pulumi.get(self, "enable_batching")

    @property
    @pulumi.getter(name="sendAfter")
    def send_after(self) -> Optional[str]:
        return pulumi.get(self, "send_after")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


