# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from . import _utilities, _tables

__all__ = [
    'ProviderBatchingArgs',
]

@pulumi.input_type
class ProviderBatchingArgs:
    def __init__(__self__, *,
                 enable_batching: Optional[pulumi.Input[bool]] = None,
                 send_after: Optional[pulumi.Input[str]] = None):
        if enable_batching is not None:
            pulumi.set(__self__, "enable_batching", enable_batching)
        if send_after is not None:
            pulumi.set(__self__, "send_after", send_after)

    @property
    @pulumi.getter(name="enableBatching")
    def enable_batching(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enable_batching")

    @enable_batching.setter
    def enable_batching(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_batching", value)

    @property
    @pulumi.getter(name="sendAfter")
    def send_after(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "send_after")

    @send_after.setter
    def send_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "send_after", value)


